@@ -3,6 +3,7 @@
 
 import unittest
 import uiautomator
+from mock import patch
 
 
 class TestMisc(unittest.TestCase):
@@ -29,3 +30,14 @@ class TestMisc(unittest.TestCase):
         for i in range(10):
             x, y = random.randint(0, 1024), random.randint(0, 720)
             self.assertEqual(uiautomator.point(x, y), {"x": x, "y": y})
+
+    def test_next_port(self):
+        with patch('socket.socket') as socket:
+            socket.return_value.connect_ex.side_effect = [0, 0, 1]
+            uiautomator._init_local_port = 9007
+            self.assertEqual(uiautomator.next_local_port(), 9010)
+
+        with patch('socket.socket') as socket:
+            socket.return_value.connect_ex.return_value = 1
+            uiautomator._init_local_port = 32764
+            self.assertEqual(uiautomator.next_local_port(), 9008)
